@@ -5,6 +5,7 @@ import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
 import pathlib
+import re
 from slugify import slugify
 
 def _digest(data):
@@ -29,7 +30,14 @@ def _digest(data):
         return hashlib.sha256( data ).hexdigest()
 
 
-def tee(plotter, *args, **kwargs):
+def tee(
+    plotter,
+    *args,
+    teeplot_outattrs={},
+    teeplot_subdir='.',
+    teeplot_transparent=True,
+    **kwargs
+):
 
     # enable TrueType fonts
     # see https://gecco-2021.sigevo.org/Paper-Submission-Instructions
@@ -41,7 +49,6 @@ def tee(plotter, *args, **kwargs):
         **{
             k : v
             for k, v in kwargs.items()
-            if k != 'teeplot_outattrs'
         }
     )
 
@@ -57,16 +64,16 @@ def tee(plotter, *args, **kwargs):
         },
         **{
             k : v
-            for k, v in kwargs.get('teeplot_outattrs', {}).items()
+            for k, v in teeplot_outattrs.items()
             if k != '_datafordigest'
         },
         **(
             {'_datadigest' : _digest( kwargs['data'] )[:16]}
             if 'data' in kwargs
             else {'_datadigest' : _digest(
-                kwargs['teeplot_outattrs']['_datafordigest']
+                teeplot_outattrs['_datafordigest']
             )[:16]}
-            if '_datafordigest' in kwargs.get('teeplot_outattrs', {})
+            if '_datafordigest' in teeplot_outattrs
             else {'_datadigest' : _digest( np.concatenate([
                 kwargs.get('x', []),
                 kwargs.get('y', []),
@@ -90,7 +97,7 @@ def tee(plotter, *args, **kwargs):
         if k.startswith('_')
     })
 
-    out_folder = 'teeplots'
+    out_folder = f'teeplots/{teeplot_subdir}'
     pathlib.Path(
         out_folder,
     ).mkdir(
@@ -100,16 +107,16 @@ def tee(plotter, *args, **kwargs):
 
     for ext, dpi in ('.pdf', 'figure'), ('.png', 300):
 
-        out_path = f'teeplots/{out_filenamer(ext)}'
+        out_path = f'{out_folder}/{out_filenamer(ext)}'
         print(out_path)
         plt.savefig(
             out_path,
             bbox_inches='tight',
-            transparent=True,
+            transparent=teeplot_transparent,
             dpi=dpi,
         )
 
-        with open(f'teeplots/{out_filenamer(ext)}.meta', 'w') as file:
+        with open(f'{out_path}.meta', 'w') as file:
             file.write( out_metamaker(ext) )
 
     return res
